Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(57)

Unified Diff: components/autofill/content/common/autofill_messages.h

Issue 208453002: Add "previewing on hover" support for password field. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Update code as per further review comments. Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/content/common/autofill_messages.h
diff --git a/components/autofill/content/common/autofill_messages.h b/components/autofill/content/common/autofill_messages.h
index 0fa84302fedee7c1cc7d7e4f5b3aeca4af514d47..cb9fc6a1252f615b3c57377c77dbfdbc73807f28 100644
--- a/components/autofill/content/common/autofill_messages.h
+++ b/components/autofill/content/common/autofill_messages.h
@@ -142,9 +142,15 @@ IPC_MESSAGE_ROUTED1(AutofillMsg_AcceptDataListSuggestion,
IPC_MESSAGE_ROUTED1(AutofillMsg_GeneratedPasswordAccepted,
base::string16 /* generated_password */)
-// Tells the renderer that the user accepted a password autofill suggestion,
-// and that renderer should set the username and password to the given values.
-IPC_MESSAGE_ROUTED2(AutofillMsg_AcceptPasswordAutofillSuggestion,
+// Tells the renderer to fill the username and password with with given
+// values.
+IPC_MESSAGE_ROUTED2(AutofillMsg_FillPasswordSuggestion,
+ base::string16 /* username */,
+ base::string16 /* password */)
+
+// Tells the renderer to preview the username and password with the given
+// values.
+IPC_MESSAGE_ROUTED2(AutofillMsg_PreviewPasswordSuggestion,
base::string16 /* username */,
base::string16 /* password */)
« no previous file with comments | « chrome/renderer/autofill/password_autofill_agent_browsertest.cc ('k') | components/autofill/content/renderer/autofill_agent.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698